@@ -30,7 +30,6 @@
 #include <gdk/gdkkeysyms.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 #include <gconf/gconf-client.h>
 #include <brasero-medium-selection.h>
 #include <brasero-volume.h>
@@ -49,7 +48,6 @@
 #include "sj-prefs.h"
 #include "sj-play.h"
 #include "sj-genres.h"
-#include "gedit-message-area.h"
 
 gboolean on_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data);
 
@@ -58,12 +56,12 @@ static void update_ui_for_album (AlbumDetails *album);
 static void set_duplication (gboolean enable);
 
 /* Prototypes for the signal blocking/unblocking in update_ui_for_album */
-void on_title_edit_changed(GtkEditable *widget, gpointer user_data);
-void on_artist_edit_changed(GtkEditable *widget, gpointer user_data);
-void on_year_edit_changed(GtkEditable *widget, gpointer user_data);
-void on_disc_number_edit_changed(GtkEditable *widget, gpointer user_data);
+G_MODULE_EXPORT void on_title_edit_changed(GtkEditable *widget, gpointer user_data);
+G_MODULE_EXPORT void on_artist_edit_changed(GtkEditable *widget, gpointer user_data);
+G_MODULE_EXPORT void on_year_edit_changed(GtkEditable *widget, gpointer user_data);
+G_MODULE_EXPORT void on_disc_number_edit_changed(GtkEditable *widget, gpointer user_data);
 
-GladeXML *glade;
+GtkBuilder *builder;
 
 SjMetadataGetter *metadata;
 SjExtractor *extractor;
@@ -104,8 +102,8 @@ static guint debug_flags = 0;
 
 #define DEFAULT_PARANOIA 4
 #define RAISE_WINDOW "raise-window"
-#define SOURCE_GLADE "../data/sound-juicer.glade"
-#define INSTALLED_GLADE DATADIR"/sound-juicer/sound-juicer.glade"
+#define SOURCE_BUILDER "../data/sound-juicer.ui"
+#define INSTALLED_BUILDER DATADIR"/sound-juicer/sound-juicer.ui"
 
 void
 sj_stock_init (void)
@@ -153,7 +151,7 @@ void sj_debug (SjDebugDomain domain, const gchar* format, ...)
     va_start (args, format);
     string = g_strdup_vprintf (format, args);
     va_end (args);
-    g_printerr (string);
+    g_printerr ("%s", string);
     g_free (string);
   }
 }
@@ -177,22 +175,21 @@ static void sj_debug_init (void)
 static void error_on_start (GError *error)
 {
   GtkWidget *dialog;
-  dialog = gtk_message_dialog_new (NULL, 0,
-                                   GTK_MESSAGE_ERROR,
-                                   GTK_BUTTONS_CLOSE,
-                                   "<b>%s</b>\n\n%s: %s.\n%s",
-                                   _("Could not start Sound Juicer"),
-                                   _("Reason"),
-                                   error->message,
-                                   _("Please consult the documentation for assistance."));
-  gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label), TRUE);
+  dialog = gtk_message_dialog_new_with_markup (NULL, 0,
+                                               GTK_MESSAGE_ERROR,
+                                               GTK_BUTTONS_CLOSE,
+                                               "<b>%s</b>\n\n%s: %s.\n%s",
+                                               _("Could not start Sound Juicer"),
+                                               _("Reason"),
+                                               error->message,
+                                               _("Please consult the documentation for assistance."));
   gtk_dialog_run (GTK_DIALOG (dialog));
 }
 
 /**
  * Clicked Quit
  */
-void on_quit_activate (GtkMenuItem *item, gpointer user_data)
+G_MODULE_EXPORT void on_quit_activate (GtkMenuItem *item, gpointer user_data)
 {
   if (on_delete_event (NULL, NULL, NULL) == FALSE) {
     gtk_main_quit ();
@@ -202,7 +199,7 @@ void on_quit_activate (GtkMenuItem *item, gpointer user_data)
 /**
  * Destroy signal Callback
  */
-void on_destroy_signal (GtkMenuItem *item, gpointer user_data)
+G_MODULE_EXPORT void on_destroy_signal (GtkMenuItem *item, gpointer user_data)
 {
    gtk_main_quit ();
 }
@@ -210,7 +207,7 @@ void on_destroy_signal (GtkMenuItem *item, gpointer user_data)
 /**
  * Clicked Eject
  */
-void on_eject_activate (GtkMenuItem *item, gpointer user_data)
+G_MODULE_EXPORT void on_eject_activate (GtkMenuItem *item, gpointer user_data)
 {
   /* first make sure we're not playing */
   stop_playback ();
@@ -218,7 +215,7 @@ void on_eject_activate (GtkMenuItem *item, gpointer user_data)
   brasero_drive_eject (drive, FALSE, NULL);
 }
 
-gboolean on_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
+G_MODULE_EXPORT gboolean on_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
   if (extracting) {
     GtkWidget *dialog;
@@ -251,7 +248,7 @@ static gboolean select_all_foreach_cb (GtkTreeModel *model,
   return FALSE;
 }
 
-void on_select_all_activate (GtkMenuItem *item, gpointer user_data)
+G_MODULE_EXPORT void on_select_all_activate (GtkMenuItem *item, gpointer user_data)
 {
   gtk_tree_model_foreach (GTK_TREE_MODEL (track_store), select_all_foreach_cb, GINT_TO_POINTER (TRUE));
   gtk_widget_set_sensitive (extract_button, TRUE);
@@ -261,7 +258,7 @@ void on_select_all_activate (GtkMenuItem *item, gpointer user_data)
   no_of_tracks_selected = total_no_of_tracks;
 }
 
-void on_deselect_all_activate (GtkMenuItem *item, gpointer user_data)
+G_MODULE_EXPORT void on_deselect_all_activate (GtkMenuItem *item, gpointer user_data)
 {
   gtk_tree_model_foreach (GTK_TREE_MODEL (track_store), select_all_foreach_cb, GINT_TO_POINTER (FALSE));
   gtk_widget_set_sensitive (extract_button, FALSE);
@@ -321,12 +318,13 @@ static void number_cell_icon_data_cb (GtkTreeViewColumn *tree_column,
 
 /* Taken from gedit */
 static void
-set_message_area_text_and_icon (GeditMessageArea *message_area,
-                                const gchar   *icon_stock_id,
-                                const gchar   *primary_text,
-                                const gchar   *secondary_text,
-                                GtkWidget *button)
+set_info_bar_text_and_icon (GtkInfoBar  *infobar,
+                            const gchar *icon_stock_id,
+                            const gchar *primary_text,
+                            const gchar *secondary_text,
+                            GtkWidget   *button)
 {
+  GtkWidget *content_area;
   GtkWidget *hbox_content;
   GtkWidget *image;
   GtkWidget *vbox;
@@ -377,8 +375,8 @@ set_message_area_text_and_icon (GeditMessageArea *message_area,
                                  gtk_widget_get_accessible (secondary_label));
   }
 
-  gedit_message_area_set_contents (GEDIT_MESSAGE_AREA (message_area),
-                                   hbox_content);
+  content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (infobar));
+  gtk_container_add (GTK_CONTAINER (content_area), hbox_content);
 }
 
 /* Taken from gedit */
@@ -404,41 +402,36 @@ set_message_area (GtkWidget *container,
 }
 
 static GtkWidget*
-musicbrainz_submit_message_area_new (char *title, char *artist)
+musicbrainz_submit_info_bar_new (char *title, char *artist)
 {
-  GtkWidget *message_area, *button;
+  GtkWidget *infobar, *button;
   char *primary_text;
 
   g_return_val_if_fail (title != NULL, NULL);
   g_return_val_if_fail (artist != NULL, NULL);
 
-  message_area = gedit_message_area_new ();
-
-  button = gedit_message_area_add_button (GEDIT_MESSAGE_AREA (message_area),
-                                          _("S_ubmit Album"),
-                                          GTK_RESPONSE_OK);
-  gedit_message_area_add_button (GEDIT_MESSAGE_AREA (message_area),
-                                 GTK_STOCK_CANCEL,
-                                 GTK_RESPONSE_CANCEL);
+  infobar = gtk_info_bar_new_with_buttons (_("S_ubmit Album"), GTK_RESPONSE_OK,
+                                           GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                           NULL);
 
   /* Translators: title, artist */
   primary_text = g_strdup_printf (_("Could not find %s by %s on MusicBrainz."), title, artist);
 
-  set_message_area_text_and_icon (GEDIT_MESSAGE_AREA (message_area),
-                                  "gtk-dialog-info",
-                                  primary_text,
-                                  _("You can improve the MusicBrainz database by adding this album."),
-                                  button);
+  set_info_bar_text_and_icon (GTK_INFO_BAR (infobar),
+                              "gtk-dialog-info",
+                              primary_text,
+                              _("You can improve the MusicBrainz database by adding this album."),
+                              button);
 
   g_free (primary_text);
 
-  return message_area;
+  return infobar;
 }
 
 static void
-musicbrainz_submit_message_area_response (GeditMessageArea *message_area,
-                                          int response_id,
-                                          gpointer user_data)
+musicbrainz_submit_info_bar_response (GtkInfoBar *infobar,
+                                      int         response_id,
+                                      gpointer    user_data)
 {
   if (response_id == GTK_RESPONSE_OK) {
     on_submit_activate (NULL, NULL);
@@ -550,21 +543,21 @@ static void update_ui_for_album (AlbumDetails *album)
 
     /* If album details don't come from MusicBrainz ask user to add them */
     if (album->metadata_source != SOURCE_MUSICBRAINZ) {
-      GtkWidget *message_area;
+      GtkWidget *infobar;
 
-      message_area = musicbrainz_submit_message_area_new (album->title, album->artist);
+      infobar = musicbrainz_submit_info_bar_new (album->title, album->artist);
 
-      set_message_area (message_area_eventbox, message_area);
+      set_message_area (message_area_eventbox, infobar);
 
-      g_signal_connect (message_area,
+      g_signal_connect (infobar,
                         "response",
-                        G_CALLBACK (musicbrainz_submit_message_area_response),
+                        G_CALLBACK (musicbrainz_submit_info_bar_response),
                         NULL);
 
-      gedit_message_area_set_default_response (GEDIT_MESSAGE_AREA (message_area),
-                                               GTK_RESPONSE_CANCEL);
+      gtk_info_bar_set_default_response (GTK_INFO_BAR (infobar),
+                                         GTK_RESPONSE_CANCEL);
 
-      gtk_widget_show (message_area);
+      gtk_widget_show (infobar);
     }
   }
 }
@@ -614,11 +607,11 @@ AlbumDetails* multiple_album_dialog(GList *albums)
     GtkTreeViewColumn *column;
     GtkCellRenderer *text_renderer = gtk_cell_renderer_text_new ();
 
-    dialog = glade_xml_get_widget (glade, "multiple_dialog");
+    dialog = GET_WIDGET ("multiple_dialog");
     g_assert (dialog != NULL);
     gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (main_window));
-    albums_listview = glade_xml_get_widget (glade, "albums_listview");
-    ok_button = glade_xml_get_widget (glade, "ok_button");
+    albums_listview = GET_WIDGET ("albums_listview");
+    ok_button       = GET_WIDGET ("ok_button");
 
     g_signal_connect (albums_listview, "row-activated", G_CALLBACK (album_row_activated), dialog);
 
@@ -765,7 +758,7 @@ static void eject_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *en
 }
 
 /**
- * The GConf key for the eject when finished option changed
+ * The GConf key for the open when finished option changed
  */
 static void open_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data)
 {
@@ -784,7 +777,7 @@ static void audio_volume_changed_cb (GConfClient *client, guint cnxn_id, GConfEn
 {
   g_assert (strcmp (entry->key, GCONF_AUDIO_VOLUME) == 0);
 
-  GtkWidget *volb = glade_xml_get_widget (glade, "volume_button");
+  GtkWidget *volb = GET_WIDGET ("volume_button");
   if (entry->value == NULL) {
     gtk_scale_button_set_value (GTK_SCALE_BUTTON (volb), 1.0);
   } else {
@@ -795,25 +788,24 @@ static void audio_volume_changed_cb (GConfClient *client, guint cnxn_id, GConfEn
 static void
 metadata_cb (SjMetadataGetter *m, GList *albums, GError *error)
 {
-  gboolean realized = GTK_WIDGET_REALIZED (main_window);
+  gboolean realized = gtk_widget_get_realized (main_window);
 
   if (realized)
-    gdk_window_set_cursor (main_window->window, NULL);
+    gdk_window_set_cursor (gtk_widget_get_window (main_window), NULL);
     /* Clear the statusbar message */
     gtk_statusbar_pop(GTK_STATUSBAR(status_bar), 0);
 
   if (error && !(error->code == SJ_ERROR_CD_NO_MEDIA)) {
     GtkWidget *dialog;
 
-    dialog = gtk_message_dialog_new (realized ? GTK_WINDOW (main_window) : NULL, 0,
-                                     GTK_MESSAGE_ERROR,
-                                     GTK_BUTTONS_CLOSE,
-                                     "<b>%s</b>\n\n%s\n%s: %s",
-                                     _("Could not read the CD"),
-                                     _("Sound Juicer could not read the track listing on this CD."),
-                                     _("Reason"),
-                                     error->message);
-    gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label), TRUE);
+    dialog = gtk_message_dialog_new_with_markup (realized ? GTK_WINDOW (main_window) : NULL, 0,
+                                                 GTK_MESSAGE_ERROR,
+                                                 GTK_BUTTONS_CLOSE,
+                                                 "<b>%s</b>\n\n%s\n%s: %s",
+                                                 _("Could not read the CD"),
+                                                 _("Sound Juicer could not read the track listing on this CD."),
+                                                 _("Reason"),
+                                                 error->message);
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
     update_ui_for_album (NULL);
@@ -884,17 +876,20 @@ static void reread_cd (gboolean ignore_no_media)
   /* TODO: remove ignore_no_media? */
   GError *error = NULL;
   GdkCursor *cursor;
-  gboolean realized = GTK_WIDGET_REALIZED (main_window);
+  GdkWindow *window;
+  gboolean realized = gtk_widget_get_realized (main_window);
+
+  window = gtk_widget_get_window (main_window);
 
   /* Make sure nothing is playing */
   stop_playback ();
 
   /* Set watch cursor */
   if (realized) {
-    cursor = gdk_cursor_new_for_display (gdk_drawable_get_display (main_window->window), GDK_WATCH);
-    gdk_window_set_cursor (main_window->window, cursor);
+    cursor = gdk_cursor_new_for_display (gdk_drawable_get_display (window), GDK_WATCH);
+    gdk_window_set_cursor (window, cursor);
     gdk_cursor_unref (cursor);
-    gdk_display_sync (gdk_drawable_get_display (main_window->window));
+    gdk_display_sync (gdk_drawable_get_display (window));
   }
 
   /* Set statusbar message */
@@ -912,7 +907,7 @@ static void reread_cd (gboolean ignore_no_media)
     update_ui_for_album (NULL);
     gtk_statusbar_pop(GTK_STATUSBAR(status_bar), 0);
     if (realized)
-      gdk_window_set_cursor (main_window->window, NULL);
+      gdk_window_set_cursor (window, NULL);
     return;
   }
 
@@ -920,20 +915,17 @@ static void reread_cd (gboolean ignore_no_media)
 
   if (error && !(error->code == SJ_ERROR_CD_NO_MEDIA && ignore_no_media)) {
     GtkWidget *dialog;
-    char *text = g_strdup_printf ("<b>%s</b>\n\n%s\n%s: %s",
-                                  _("Could not read the CD"),
-                                  _("Sound Juicer could not read the track listing on this CD."),
-                                  _("Reason"),
-                                  error->message);
 
     dialog = gtk_message_dialog_new (realized ? GTK_WINDOW (main_window) : NULL, 0,
                                      GTK_MESSAGE_ERROR,
                                      GTK_BUTTONS_CLOSE,
-                                     text);
+                                     "%s", _("Could not read the CD"));
+    gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG (dialog),
+                                                "%s\n%s: %s",
+                                                _("Sound Juicer could not read the track listing on this CD."),
+                                                _("Reason"),
+                                                error->message);
 
-    g_free (text);
-
-    gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label), TRUE);
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
     g_error_free (error);
@@ -991,15 +983,14 @@ set_drive_from_device (const char *device)
     GtkWidget *dialog;
     char *message;
     message = g_strdup_printf (_("Sound Juicer could not use the CD-ROM device '%s'"), device);
-    dialog = gtk_message_dialog_new (GTK_WINDOW (main_window),
-                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-                                     GTK_MESSAGE_ERROR,
-                                     GTK_BUTTONS_CLOSE,
-                                     "<b>%s</b>\n\n%s",
-                                     message,
-                                     _("HAL daemon may not be running."));
+    dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (main_window),
+                                                 GTK_DIALOG_DESTROY_WITH_PARENT,
+                                                 GTK_MESSAGE_ERROR,
+                                                 GTK_BUTTONS_CLOSE,
+                                                 "<b>%s</b>\n\n%s",
+                                                 message,
+                                                 _("HAL daemon may not be running."));
     g_free (message);
-    gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label), TRUE);
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
     return;
@@ -1024,18 +1015,17 @@ set_device (const char* device, gboolean ignore_no_media)
     error = g_strerror (errno);
     message = g_strdup_printf (_("Sound Juicer could not access the CD-ROM device '%s'"), device);
 
-    dialog = gtk_message_dialog_new (GTK_WINDOW (main_window),
-                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-                                     GTK_MESSAGE_ERROR,
-                                     GTK_BUTTONS_CLOSE,
-                                     "<b>%s</b>\n\n%s\n%s: %s",
-                                     _("Could not read the CD"),
-                                     message,
-                                     _("Reason"),
-                                     error);
+    dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (main_window),
+                                                 GTK_DIALOG_DESTROY_WITH_PARENT,
+                                                 GTK_MESSAGE_ERROR,
+                                                 GTK_BUTTONS_CLOSE,
+                                                 "<b>%s</b>\n\n%s\n%s: %s",
+                                                 _("Could not read the CD"),
+                                                 message,
+                                                 _("Reason"),
+                                                 error);
     g_free (message);
 
-    gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label), TRUE);
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
 
@@ -1116,14 +1106,13 @@ static void device_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *e
     if (device == NULL) {
 #ifndef IGNORE_MISSING_CD
       GtkWidget *dialog;
-      dialog = gtk_message_dialog_new (GTK_WINDOW (main_window),
-                                       GTK_DIALOG_DESTROY_WITH_PARENT,
-                                       GTK_MESSAGE_ERROR,
-                                       GTK_BUTTONS_CLOSE,
-                                       "<b>%s</b>\n\n%s",
-                                       _("No CD-ROM drives found"),
-                                       _("Sound Juicer could not find any CD-ROM drives to read."));
-      gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label), TRUE);
+      dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (main_window),
+                                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+                                                   GTK_MESSAGE_ERROR,
+                                                   GTK_BUTTONS_CLOSE,
+                                                   "<b>%s</b>\n\n%s",
+                                                   _("No CD-ROM drives found"),
+                                                   _("Sound Juicer could not find any CD-ROM drives to read."));
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
       exit (1);
@@ -1220,7 +1209,7 @@ static void http_proxy_port_changed_cb (GConfClient *client, guint cnxn_id, GCon
 /**
  * Clicked on Reread in the UI (button/menu)
  */
-void on_reread_activate (GtkWidget *button, gpointer user_data)
+G_MODULE_EXPORT void on_reread_activate (GtkWidget *button, gpointer user_data)
 {
   reread_cd (FALSE);
 }
@@ -1228,7 +1217,7 @@ void on_reread_activate (GtkWidget *button, gpointer user_data)
 /**
  * Clicked the Submit menu item in the UI
  */
-void on_submit_activate (GtkWidget *menuitem, gpointer user_data)
+G_MODULE_EXPORT void on_submit_activate (GtkWidget *menuitem, gpointer user_data)
 {
   GError *error = NULL;
 
@@ -1236,16 +1225,15 @@ void on_submit_activate (GtkWidget *menuitem, gpointer user_data)
       if (!gtk_show_uri (NULL, current_submit_url, GDK_CURRENT_TIME, &error)) {
       GtkWidget *dialog;
 
-      dialog = gtk_message_dialog_new (GTK_WINDOW (main_window),
-                                       GTK_DIALOG_DESTROY_WITH_PARENT,
-                                       GTK_MESSAGE_ERROR,
-                                       GTK_BUTTONS_CLOSE,
-                                       "<b>%s</b>\n\n%s\n%s: %s",
-                                       _("Could not open URL"),
-                                       _("Sound Juicer could not open the submission URL"),
-                                       _("Reason"),
-                                       error->message);
-      gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label), TRUE);
+      dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (main_window),
+                                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+                                                   GTK_MESSAGE_ERROR,
+                                                   GTK_BUTTONS_CLOSE,
+                                                   "<b>%s</b>\n\n%s\n%s: %s",
+                                                   _("Could not open URL"),
+                                                   _("Sound Juicer could not open the submission URL"),
+                                                   _("Reason"),
+                                                   error->message);
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
       g_error_free (error);
@@ -1388,7 +1376,7 @@ remove_musicbrainz_ids (AlbumDetails *album)
 #undef UNSET
 }
 
-void on_title_edit_changed(GtkEditable *widget, gpointer user_data) {
+G_MODULE_EXPORT void on_title_edit_changed(GtkEditable *widget, gpointer user_data) {
   g_return_if_fail (current_album != NULL);
 
   remove_musicbrainz_ids (current_album);
@@ -1399,7 +1387,7 @@ void on_title_edit_changed(GtkEditable *widget, gpointer user_data) {
   current_album->title = gtk_editable_get_chars (widget, 0, -1); /* get all the characters */
 }
 
-void on_artist_edit_changed(GtkEditable *widget, gpointer user_data) {
+G_MODULE_EXPORT void on_artist_edit_changed(GtkEditable *widget, gpointer user_data) {
   GtkTreeIter iter;
   TrackDetails *track;
   gchar *current_track_artist, *former_album_artist = NULL;
@@ -1446,7 +1434,7 @@ void on_artist_edit_changed(GtkEditable *widget, gpointer user_data) {
   g_free (former_album_artist);
 }
 
-void on_genre_edit_changed(GtkEditable *widget, gpointer user_data) {
+G_MODULE_EXPORT void on_genre_edit_changed(GtkEditable *widget, gpointer user_data) {
   g_return_if_fail (current_album != NULL);
   if (current_album->genre) {
     g_free (current_album->genre);
@@ -1454,7 +1442,7 @@ void on_genre_edit_changed(GtkEditable *widget, gpointer user_data) {
   current_album->genre = gtk_editable_get_chars (widget, 0, -1); /* get all the characters */
 }
 
-void on_year_edit_changed(GtkEditable *widget, gpointer user_data) {
+G_MODULE_EXPORT void on_year_edit_changed(GtkEditable *widget, gpointer user_data) {
   const gchar* yearstr;
   int year;
 
@@ -1471,7 +1459,7 @@ void on_year_edit_changed(GtkEditable *widget, gpointer user_data) {
   }
 }
 
-void on_disc_number_edit_changed(GtkEditable *widget, gpointer user_data) {
+G_MODULE_EXPORT void on_disc_number_edit_changed(GtkEditable *widget, gpointer user_data) {
     const gchar* discstr;
     int disc_number;
 
@@ -1481,7 +1469,7 @@ void on_disc_number_edit_changed(GtkEditable *widget, gpointer user_data) {
     current_album->disc_number = disc_number;
 }
 
-void on_contents_activate(GtkWidget *button, gpointer user_data) {
+G_MODULE_EXPORT void on_contents_activate(GtkWidget *button, gpointer user_data) {
   GError *error = NULL;
 
   gtk_show_uri (NULL, "ghelp:sound-juicer", GDK_CURRENT_TIME, &error);
@@ -1583,7 +1571,7 @@ is_cd_duplication_available()
 /**
  * Clicked on duplicate in the UI (button/menu)
  */
-void on_duplicate_activate (GtkWidget *button, gpointer user_data)
+G_MODULE_EXPORT void on_duplicate_activate (GtkWidget *button, gpointer user_data)
 {
   GError *error = NULL;
   const gchar* device;
@@ -1592,16 +1580,15 @@ void on_duplicate_activate (GtkWidget *button, gpointer user_data)
   if (!g_spawn_command_line_async (g_strconcat ("brasero -c ", device, NULL), &error)) {
       GtkWidget *dialog;
 
-      dialog = gtk_message_dialog_new (GTK_WINDOW (main_window),
-                                       GTK_DIALOG_DESTROY_WITH_PARENT,
-                                       GTK_MESSAGE_ERROR,
-                                       GTK_BUTTONS_CLOSE,
-                                       "<b>%s</b>\n\n%s\n%s: %s",
-                                       _("Could not duplicate disc"),
-                                       _("Sound Juicer could not duplicate the disc"),
-                                       _("Reason"),
-                                       error->message);
-      gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label), TRUE);
+      dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (main_window),
+                                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+                                                   GTK_MESSAGE_ERROR,
+                                                   GTK_BUTTONS_CLOSE,
+                                                   "<b>%s</b>\n\n%s\n%s: %s",
+                                                   _("Could not duplicate disc"),
+                                                   _("Sound Juicer could not duplicate the disc"),
+                                                   _("Reason"),
+                                                   error->message);
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
       g_error_free (error);
@@ -1704,43 +1691,42 @@ int main (int argc, char **argv)
   /* init gnome-media-profiles */
   gnome_media_profiles_init (gconf_client);
 
-  glade_init ();
-  if (g_file_test (SOURCE_GLADE, G_FILE_TEST_EXISTS) != FALSE) {
-    glade = glade_xml_new (SOURCE_GLADE, NULL, NULL);
+  builder = gtk_builder_new ();
+  if (g_file_test (SOURCE_BUILDER, G_FILE_TEST_EXISTS) != FALSE) {
+    gtk_builder_add_from_file (builder, SOURCE_BUILDER, &error);
   } else {
-    glade = glade_xml_new (INSTALLED_GLADE, NULL, NULL);
+    gtk_builder_add_from_file (builder, INSTALLED_BUILDER, &error);
   }
-  if (glade == NULL) {
-    error = g_error_new (g_quark_from_static_string ("sound-juicer"),
-                         1, /* this is made up */
-                         _("The interface file for Sound Juicer could not be read."));
+
+  if (error != NULL) {
     error_on_start (error);
     g_error_free (error);
     exit (1);
   }
-  glade_xml_signal_autoconnect (glade);
 
-  main_window = glade_xml_get_widget (glade, "main_window");
-  message_area_eventbox = glade_xml_get_widget (glade, "message_area_eventbox");
-  select_all_menuitem = glade_xml_get_widget (glade, "select_all");
-  deselect_all_menuitem = glade_xml_get_widget (glade, "deselect_all");
-  submit_menuitem = glade_xml_get_widget (glade, "submit");
-  title_entry = glade_xml_get_widget (glade, "title_entry");
-  artist_entry = glade_xml_get_widget (glade, "artist_entry");
-  duration_label = glade_xml_get_widget (glade, "duration_label");
-  genre_entry = glade_xml_get_widget (glade, "genre_entry");
-  year_entry = glade_xml_get_widget (glade, "year_entry");
-  disc_number_entry = glade_xml_get_widget (glade, "disc_number_entry");
-  track_listview = glade_xml_get_widget (glade, "track_listview");
-  extract_button = glade_xml_get_widget (glade, "extract_button");
-  extract_menuitem = glade_xml_get_widget (glade, "extract_menuitem");
-  play_button = glade_xml_get_widget (glade, "play_button");
-  play_menuitem = glade_xml_get_widget (glade, "play_menuitem");
-  next_menuitem = glade_xml_get_widget (glade, "next_track_menuitem");
-  prev_menuitem = glade_xml_get_widget (glade, "previous_track_menuitem");
-  status_bar = glade_xml_get_widget (glade, "status_bar");
-  duplicate = glade_xml_get_widget (glade, "duplicate_menuitem");
-  eject = glade_xml_get_widget (glade, "eject");
+  gtk_builder_connect_signals (builder, NULL);
+
+  main_window           = GET_WIDGET ("main_window");
+  message_area_eventbox = GET_WIDGET ("message_area_eventbox");
+  select_all_menuitem   = GET_WIDGET ("select_all");
+  deselect_all_menuitem = GET_WIDGET ("deselect_all");
+  submit_menuitem       = GET_WIDGET ("submit");
+  title_entry           = GET_WIDGET ("title_entry");
+  artist_entry          = GET_WIDGET ("artist_entry");
+  duration_label        = GET_WIDGET ("duration_label");
+  genre_entry           = GET_WIDGET ("genre_entry");
+  year_entry            = GET_WIDGET ("year_entry");
+  disc_number_entry     = GET_WIDGET ("disc_number_entry");
+  track_listview        = GET_WIDGET ("track_listview");
+  extract_button        = GET_WIDGET ("extract_button");
+  extract_menuitem      = GET_WIDGET ("extract_menuitem");
+  play_button           = GET_WIDGET ("play_button");
+  play_menuitem         = GET_WIDGET ("play_menuitem");
+  next_menuitem         = GET_WIDGET ("next_track_menuitem");
+  prev_menuitem         = GET_WIDGET ("previous_track_menuitem");
+  status_bar            = GET_WIDGET ("status_bar");
+  duplicate             = GET_WIDGET ("duplicate_menuitem");
+  eject                 = GET_WIDGET ("eject");
 
   { /* ensure that the play/pause button's size is constant */
     GtkWidget *fake_button1, *fake_button2;
